@@ -1,4 +1,4 @@
-from . import toblo
+from . import retrieval, toblo
 
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 __authors__ = ['Christiane Duscha <christiane.duscha@uib.no']
\ No newline at end of file
